@@ -7,7 +7,7 @@ UV S_queue_alloc();
 void S_thread_send(pTHX_ UV thread_id, message* message);
 void S_queue_send(pTHX_ UV queue_id, message* message);
 void S_queue_receive(pTHX_ UV queue_id, message* message);
-void S_queue_receive_nb_(pTHX_ UV queue_id, message* message);
+bool S_queue_receive_nb(pTHX_ UV queue_id, message* message);
 void thread_add_listener(pTHX, UV talker, UV listener);
 void S_send_listeners(pTHX_ mthread* thread, message* message);
 
